@@ -10,7 +10,7 @@
 
 #include <QGraphicsScene>
 
-class KgTheme;
+class KGameTheme;
 
 class SceneInterface : public QGraphicsScene
 {
@@ -28,7 +28,7 @@ public:
     virtual void setUpdateInterval(int) = 0;
     virtual void setSoundsEnabled(bool) = 0;
     virtual void readSettings() = 0;
-    virtual void loadTheme(const KgTheme *theme) = 0;
+    virtual void loadTheme(const KGameTheme *theme) = 0;
     virtual void startGame() = 0;
     virtual void stopGame() = 0;
     virtual void pauseGame(bool, bool fromUI = false) = 0;
